/*
 * APPLICATION PRINT SERVICES LIBRARY
 *
 * (C) Copyright 2001-2002 Xandros Corporation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *
 *
 *        File: apsuiqt.h
 *
 * Description:
 *
 */
#ifndef APS_UI_QT_H
#define APS_UI_QT_H

#include <qmap.h>
#include <qprinter.h>

class QWidget;
class ApsJobAttrObject;
class ApsJobAttrUIHelper;
class CTabOptions;
class CTabPageSettings;
class CTabProfiles;


/*
 * This class provides some common functionality for property tabs
 *
*/
class ApsJobAttrUIHelper
{
	friend struct CTabOptions;
	friend class CTabPageSettings;
	friend struct CTabProfiles;

public:
	ApsJobAttrUIHelper(const char *szPrinterName);
	~ApsJobAttrUIHelper();

	QWidget *createOptionsTab(QWidget *parent, bool bReadOnly = false);
	QWidget *createPageSettingsTab(QWidget *parent, bool bReadOnly = false);
#ifdef HAVE_PROFILES_TAB
	QWidget *createProfilesTab(QWidget *parent, bool bReadOnly = false);
#endif

	static QPrinter::PageSize GetEnumForPageSize(const char *szPage);

	ApsJobAttrObject *getJobAttrObj() { return m_pJobAttrObj; };
	ApsJobAttrObject *getDefaultJobAttrObj() { return m_pDefaultJobAttrObj; };

/**
 * This function is called to fill the structure @p opts with the selected attributes from the dialog
 * page. If @p incldef is true, include also attributes with default values, otherwise discard them.
 * @param widget the widget to update
 * @param opts the attributes set to fill
 * @param incldef if true, include also options with default values
 * @see setAttributes()
 */
	void getAttributes(QWidget *widget, QMap<QString,QString>& opts, bool incldef = false);

/**
 * This function is called to update the current page with the attributes contained in @p opts.
 * @param widget the widget to update
 * @param opts the structure containing the options to update the page
 */
	void setAttributes(QWidget *widget, const QMap<QString,QString>& opts);

	void getAttributes(QMap<QString,QString>& opts, bool incldef);
	void setAttributes(const QMap<QString,QString>& opts);

	bool setJobAttrSetting(const char *attributeID, const char *setting);
	void saveJobAttrSetting(const char *attributeID, const char *setting);

private:
	ApsJobAttrObject *m_pJobAttrObj;
	ApsJobAttrObject *m_pDefaultJobAttrObj;
	QString m_strPrinterName;
	QMap<QString,QString> m_ChangedAttributes;
};

// methods to use with dlopen and dlsym

#  ifdef __cplusplus
extern "C"
{
#  endif /* __cplusplus */

	ApsJobAttrUIHelper *createApsJobAttrUIHelper(const char *szPrinterName);
	void deleteApsJobAttrUIHelper(ApsJobAttrUIHelper *thisBase);

	QWidget * ApsJobAttrUIHelper_CreateOptionsTab(ApsJobAttrUIHelper *thisBase, QWidget *parent, int bReadonly);
	QWidget * ApsJobAttrUIHelper_CreatePageSettingsTab(ApsJobAttrUIHelper *thisBase, QWidget *parent, int bReadonly);
#ifdef HAVE_PROFILES_TAB
	QWidget * ApsJobAttrUIHelper_CreateProfilesTab(ApsJobAttrUIHelper *thisBase, QWidget *parent, int bReadonly);
#endif

/**
 * This function is called to fill the structure @p opts with the selected attributes from the dialog
 * page. If @p incldef is true, include also attributes with default values, otherwise discard them.
 * @param widget the widget to update
 * @param opts the attributes set to fill
 * @param incldef if true, include also options with default values
 * @see setAttributes()
 */
	void ApsJobAttrUIHelper_GetAttributes(ApsJobAttrUIHelper *thisBase, QWidget *widget, QMap<QString,QString> *opts, bool incldef);

/**
 * This function is called to update the current page with the attributes contained in @p opts.
 * @param widget the widget to update
 * @param opts the structure containing the options to update the page
 */
	void ApsJobAttrUIHelper_SetAttributes(ApsJobAttrUIHelper *thisBase, QWidget *widget, const QMap<QString,QString> *opts);

#  ifdef __cplusplus
}
#  endif /* __cplusplus */

#define SAVE_JOB_ATTR(id, val)    if (getHelper()) getHelper()->saveJobAttrSetting(id, val);

#endif
